Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProgressBar ¶ added in v0.14.0
type ProgressBar struct {
// contains filtered or unexported fields
}
ProgressBar wraps a Bubbletea progress bar for simple non-interactive use. Use this for determinate operations where you know the total count.
func NewProgressBar ¶ added in v0.14.0
func NewProgressBar(total int, message string) *ProgressBar
NewProgressBar creates a new progress bar with the given total and message.
func (*ProgressBar) SetProgress ¶ added in v0.14.0
func (p *ProgressBar) SetProgress(current int, message string)
SetProgress updates the current progress and message.
func (*ProgressBar) Start ¶ added in v0.14.0
func (p *ProgressBar) Start()
Start begins the progress bar display.
func (*ProgressBar) Stop ¶ added in v0.14.0
func (p *ProgressBar) Stop()
Stop stops the progress bar and clears the line.
func (*ProgressBar) Total ¶ added in v0.14.0
func (p *ProgressBar) Total() int
Total returns the total count for the progress bar.
Click to show internal directories.
Click to hide internal directories.