Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FileLock ¶
type FileLock struct {
// contains filtered or unexported fields
}
FileLock provides exclusive file-based locking using flock.
func NewFileLock ¶
NewFileLock creates a new file lock for the given path. The lock file will be created if it doesn't exist.
Click to show internal directories.
Click to hide internal directories.