cmd

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 23, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package cmd provides helpers for executing shell commands with proper error handling.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Output

func Output(cmd *exec.Cmd) ([]byte, error)

Output executes a command and returns stdout, with stderr in error if it fails

func Run

func Run(cmd *exec.Cmd) error

Run executes a command and returns stderr in the error message if it fails

Types

This section is empty.

Jump to