resolve

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 23, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package resolve provides unified target resolution for worktree commands.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Target

type Target struct {
	ID       int
	Branch   string
	MainRepo string
	Path     string
}

Target represents a resolved worktree target

func ByID

func ByID(id int, scanDir string) (*Target, error)

ByID resolves a worktree target by its numeric ID only. Returns error if ID not found, worktree was removed, or path no longer exists.

Jump to